@@ -1,11 +1,13 @@
 import requests
 import base64
 import json 
+from ..config import base_url, api_token
 
-base_url = "https://dev-aicloud-gateway.logicplum.com/api/v2"
-api_token = "i6DmueJGRHw1UYVcyKXmjSprOEWDRtCC7oqxJKuKzz7wXcAHHO9UPUQLlWt23AHx"
+def reports(deployment_id,client_token):
+    data = {
+    "deployment_id": deployment_id
+    }
 
-def reports(data,client_token):
     url = f'{base_url}/plot/report'
     headers = {"Authorization":client_token}
     response = requests.post(url, data=data,headers=headers)
